==> rong-ui-react-0.0.5.tgz: package/es/checkbox/group.js <==
var _excluded = ["children", "options", "className", "style"];

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, memo, useCallback, useEffect, useState } from 'react';
import Checkbox from './checkbox';
import { classNames } from '../_util/assist';
import { Provider } from './groupContext';
var prefixCls = 'r-checkbox-group';
var CheckboxGroup = /*#__PURE__*/forwardRef(function (props, ref) {
  var children = props.children,
      _props$options = props.options,
      options = _props$options === void 0 ? [] : _props$options,
      className = props.className,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded);

  var _useState = useState(restProps.value || []),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  console.log('group mounted or update');
  useEffect(function () {
    if ('value' in restProps) {
      setValue(restProps.value || []);
    }
  }, [restProps.value]); // eslint-disable-line

  var getOptions = function getOptions() {
    return options.map(function (option) {
      if (typeof option === 'string') {
        return {
          label: option,
          value: option,
          style: {},
          disabled: false,
          onChange: function onChange() {}
        };
      }

      return option;
    });
  };

  if (options.length) {
    children = getOptions().map(function (option) {
      return /*#__PURE__*/React.createElement(Checkbox, {
        key: option.value.toString(),
        disabled: 'disabled' in option ? option.disabled : restProps.disabled,
        value: option.value,
        type: option.type,
        name: option.name,
        checked: value.indexOf(option.value) !== -1,
        onChange: option.onChange,
        style: option.style,
        className: option.className
      }, option.label);
    });
  }

  var onChange = useCallback(function (e) {
    var newValue = context.fields.filter(function (item) {
      return item.state.checked === true;
    }).map(function (item) {
      return item.props.value;
    });

    if (!('value' in props)) {
      setValue(newValue);
    }

    restProps.onChange && restProps.onChange(newValue, e);
  }, []);
  var context = React.useMemo(function () {
    return {
      onChange: onChange,
      value: value,
      disabled: props.disabled,
      name: props.name,
      fields: []
    };
  }, [value, props.disabled, props.name, onChange]);
  var wrapCls = classNames([prefixCls, props.className]);
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    style: style
  }, /*#__PURE__*/React.createElement(Provider, {
    value: context
  }, children));
});
CheckboxGroup.displayName = 'CheckboxGroup';
export default /*#__PURE__*/memo(CheckboxGroup);

==> rong-ui-react-0.0.8.tgz: package/es/checkbox/group.js <==
var _excluded = ["children", "options", "className", "style"];
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, memo, useCallback, useEffect, useState } from 'react';
import Checkbox from './checkbox';
import { classNames } from '../_util/assist';
import { Provider } from './groupContext';
var prefixCls = 'r-checkbox-group';
var CheckboxGroup = /*#__PURE__*/forwardRef(function (props, ref) {
  var children = props.children,
    _props$options = props.options,
    options = _props$options === void 0 ? [] : _props$options,
    className = props.className,
    style = props.style,
    restProps = _objectWithoutProperties(props, _excluded);
  var _useState = useState(restProps.value || []),
    _useState2 = _slicedToArray(_useState, 2),
    value = _useState2[0],
    setValue = _useState2[1];
  console.log('group mounted or update');
  useEffect(function () {
    if ('value' in restProps) {
      setValue(restProps.value || []);
    }
  }, [restProps.value]); // eslint-disable-line

  var getOptions = function getOptions() {
    return options.map(function (option) {
      if (typeof option === 'string') {
        return {
          label: option,
          value: option,
          style: {},
          disabled: false,
          onChange: function onChange() {}
        };
      }
      return option;
    });
  };
  if (options.length) {
    children = getOptions().map(function (option) {
      return /*#__PURE__*/React.createElement(Checkbox, {
        key: option.value.toString(),
        disabled: 'disabled' in option ? option.disabled : restProps.disabled,
        value: option.value,
        type: option.type,
        name: option.name,
        checked: value.indexOf(option.value) !== -1,
        onChange: option.onChange,
        style: option.style,
        className: option.className
      }, option.label);
    });
  }
  var onChange = useCallback(function (e) {
    var newValue = context.fields.filter(function (item) {
      return item.state.checked === true;
    }).map(function (item) {
      return item.props.value;
    });
    if (!('value' in props)) {
      setValue(newValue);
    }
    restProps.onChange && restProps.onChange(newValue, e);
  }, []);
  var context = React.useMemo(function () {
    return {
      onChange: onChange,
      value: value,
      disabled: props.disabled,
      name: props.name,
      fields: []
    };
  }, [value, props.disabled, props.name, onChange]);
  var wrapCls = classNames([prefixCls, props.className]);
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    style: style
  }, /*#__PURE__*/React.createElement(Provider, {
    value: context
  }, children));
});
CheckboxGroup.displayName = 'CheckboxGroup';
export default /*#__PURE__*/memo(CheckboxGroup);
